import type { User } from './user';
import type { LoggerConfig } from '../core/logger';
import type { DatabaseConfig } from '../database';
export interface ProviderConfig {
    enabled: boolean;
    clientId?: string;
    clientSecret?: string;
}
export interface SecurityConfig {
    level: 'strict' | 'moderate' | 'relaxed';
    maxLoginAttempts?: number;
    lockoutDuration?: number;
    twoFactor?: {
        enabled: boolean;
        method?: 'totp' | 'email' | 'sms';
    };
    routeProtection?: {
        protectedRoutes?: {
            [route: string]: {
                allowedRoles: string[];
                redirectPath?: string;
            };
        };
        redirectPath?: string;
    };
    passwordPolicy?: {
        minLength?: number;
        maxLength?: number;
        requireUppercase?: boolean | number;
        requireLowercase?: boolean | number;
        requireNumbers?: boolean | number;
        requireSpecialChars?: boolean | number;
        specialChars?: string;
    };
}
export interface EventHandlers {
    onSignIn?: (user: User) => Promise<void>;
    onRegistration?: (user: User) => Promise<void>;
    onPasswordReset?: (user: User) => Promise<void>;
}
export interface GuardianAuthConfig {
    database?: DatabaseConfig;
    providers: {
        google?: ProviderConfig;
        github?: ProviderConfig;
        credentials?: ProviderConfig & {
            passwordless?: boolean;
            additionalUserFields?: string[];
            allowRegistration?: boolean;
        };
    };
    security: SecurityConfig;
    events?: EventHandlers;
    logging: LoggerConfig;
    advanced?: {
        sessionStrategy?: 'jwt' | 'database';
        tokenEncryption?: boolean;
        rateLimiting?: {
            enabled: boolean;
            requestsPerMinute?: number;
        };
    };
}
export declare const DefaultGuardianAuthConfig: GuardianAuthConfig;
